from distutils.core import setup
setup(
    name = "tirx",
    packages = ["tirx"],
    version = "0.1",
    license="Apache-2.0",
    description = "Machine learning for systems",
    author = "",
    author_email = "tianqi.tchen@gmail.com",
    url = "https://github.com/mlc-ai",
    keywords = [],
    install_requires=[],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Build Tools",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3"
  ],
)
